SystemOrganization addCategory: #ConfigurationOfWebStore!

Object subclass: #ConfigurationOfWebStore
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfWebStore'!

!ConfigurationOfWebStore class methodsFor: 'development support' stamp: 'StuartHerring 10/28/2012 13:44'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfWebStore class methodsFor: 'private' stamp: 'StuartHerring 10/28/2012 13:44'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfWebStore class methodsFor: 'private' stamp: 'StuartHerring 10/28/2012 13:44'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfWebStore class methodsFor: 'private' stamp: 'StuartHerring 10/28/2012 13:44'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfWebStore class methodsFor: 'metacello tool support' stamp: 'StuartHerring 10/28/2012 13:44'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfWebStore class methodsFor: 'loading' stamp: 'StuartHerring 10/28/2012 13:44'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfWebStore class methodsFor: 'loading' stamp: 'StuartHerring 10/28/2012 13:44'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfWebStore class methodsFor: 'loading' stamp: 'StuartHerring 10/28/2012 13:44'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfWebStore class methodsFor: 'accessing' stamp: 'StuartHerring 10/28/2012 13:44'!
project

	^self new project! !

!ConfigurationOfWebStore class methodsFor: 'development support' stamp: 'StuartHerring 10/28/2012 13:44'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfWebStore methodsFor: 'baselines' stamp: 'StuartHerring 10/28/2012 14:19'!
baseline20: spec
	<version: '2.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://stuartherring.com/mc/WebStore'.
		spec 
			project: 'Seaside28' with: [
				spec
					className: 'ConfigurationOfSeaside28';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					loads: #('Seaside2' 'Scriptaculous') ];
			project: 'Seaside28-All' with: [
				spec
					className: 'ConfigurationOfSeaside28';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Magma' with: [
				spec
					className: 'ConfigurationOfMagmaSH';
					versionString: #'bleedingEdge';
					repository: 'http://stuartherring.net/mc/misc' ];
			project: 'XMLSupport' with: [
				spec
					className: 'ConfigurationOfXMLSupport';
					versionString: #'stable';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		spec package: 'Magma seaside' with: [
			spec repository: 'http://www.squeaksource.com/Magma' ].
		
		spec package: 'SeasideTesting-R1.5' with: [
				spec repository: 'http://stuartherring.net/mc/misc' ].
			
		spec package: 'SMock' with: [
				spec repository: 'http://stuartherring.net/mc/misc'].
			
		spec 
			package: 'WebStore' with: [
				spec requires: #('Seaside28' 'MagmaSH' 'XMLSupport' 'Magma seaside'). ];
			package: 'WebStoreTests' with: [
				spec requires: #('WebStore' 'SeasideTesting-R1.5' 'SMock'). ].
		spec 
			group: 'default' with: #('Core' );
			group: 'Core' with: #('WebStore' );
			group: 'Tests' with: #('WebStoreTests' );
			group: 'Development' with: #('Core' 'Tests' 'Seaside28-All') 
		].
! !

!ConfigurationOfWebStore methodsFor: 'accessing' stamp: 'StuartHerring 10/28/2012 13:44'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !
